Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

F |
| fadeTooltip $.jqplot.CanvasOverlay$.jqplot.Highlighter
| fill Global$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.LineRenderer$.jqplot.PieRenderer$.jqplot.shadowRenderer$.jqplot.shapeRenderer Series
| fillAlpha, Series
| fillAndStroke, Series
| fillAxis, Series
| fillBetween, jqPlot
| fillColor $.jqplot.LineRenderer Series
| fillDownBody, $.jqplot.OHLCRenderer
| fillRect, $.jqplot.shapeRenderer
| fillStyle, $.jqplot.shapeRenderer
| fillToValue, Series
| fillToZero, Series
| fillUpBody, $.jqplot.OHLCRenderer
| followMouse, $.jqplot.Cursor
| fontFamily $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer Legend Title
| fontSize $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer jqPlot Legend Title
| fontStretch $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
| fontWeight $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
| forceTickAt0, $.jqplot.LinearAxisRenderer
| forceTickAt100, $.jqplot.LinearAxisRenderer
| formatString $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.Highlighter$.jqplot.PointLabels
| formatter $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.PointLabels
| Functions $.jqplot.BezierCurveRenderer.js$.jqplot.MekkoRenderer$.jqplot.shapeRenderer
G |
| get, $.jqplot.ThemeEngine
| getThemeNames, $.jqplot.ThemeEngine
| getThemes, $.jqplot.ThemeEngine
| GPL Version 2
| grid, jqPlot
| Grid
| gridLineColor, Grid
| gridLineWidth, Grid
| groups, $.jqplot.BarRenderer
H |
| hideZeros, $.jqplot.PointLabels
| highlightAlpha, $.jqplot.BubbleRenderer
| highlightColor, $.jqplot.LineRenderer
| highlightColors Global$.jqplot.BarRenderer$.jqplot.BubbleRenderer$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| highlightMouseDown Global$.jqplot.BarRenderer$.jqplot.BubbleRenderer$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.LineRenderer$.jqplot.PieRenderer
| highlightMouseOver Global$.jqplot.BarRenderer$.jqplot.BubbleRenderer$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.LineRenderer$.jqplot.PieRenderer
| hlc, $.jqplot.OHLCRenderer
| Hooks, $.jqplot
| HorizontalLine
| hubRadius, $.jqplot.MeterGaugeRenderer

true = fade in/out tooltip, flase = show/hide tooltip

> this.fadeTooltip = true

true = fade in/out tooltip, flase = show/hide tooltip

> this.fill = true

True to fill the bars.

> this.fill = true

true or false, whether to fil the slices.

> this.fill = true

true or false, whether to fill the areas.
True to fill area between bands [default: true].

> this.fill = true

true or false, whether to fil the slices.

> this.fill = false

whether to fill the shape.

> this.fill = false

whether to fill the shape.

> this.fill = false

true or false, whether to fill under lines or in bars.

> this.fillAlpha

Alpha transparency to apply to the fill under the line.

> this.fillAndStroke = false

If true will stroke the line (with color this.color) as well as fill under it.

> this.fillAxis = 'y'

Either ‘x’ or ‘y’.

> this.fillBetween = { series1: null, series2: null, color: null, baseSeries: 0, fill: true }

Fill between 2 line series in a plot.
css color spec for filled area.

> this.fillColor

CSS color spec to use for fill under line.

> this.fillDownBody = true

true to render a “down” day (close price lower than open price) with a filled candlestick body.

> this.fillRect = false

true to draw shape as a filled rectangle.

> this.fillStyle = '#999999'

css color spec for the fill style.

> this.fillToValue = 0

fill a filled series to this value on the fill axis.

> this.fillToZero = false

true will force bar and filled series to fill toward zero on the fill Axis.

> this.fillUpBody = false

true to render an “up” day (close price greater than open price) with a filled candlestick body.

> this.followMouse = false

Tooltip follows the mouse, it is not at a fixed location.

> this.fontFamily

css spec for the font-family css attribute.

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

CSS spec for the font-family css attribute.

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

css spec for the font-family css attribute.

> this.fontFamily

css font-family spec for the legend text.

> this.fontFamily

css font-family spec for the text.

> this.fontSize

css spec for the font-size css attribute.

> this.fontSize = '11pt'

CSS spec for font size.

> this.fontSize = '10pt'

CSS spec for font size.

> this.fontSize

css spec for the font-size attribute.

> this.fontSize

css font-size spec for the legend text.

> this.fontSize

css font-size spec for the text.

> this.fontStretch = 1.0

Multiplier to condense or expand font width.

> this.fontStretch = 1.0

Multiplier to condense or expand font width.

> this.fontWeight = 'normal'

> this.fontWeight = 'normal'

CSS spec for fontWeight

> this.forceTickAt0 = false

This will ensure that there is always a tick mark at 0.

> this.forceTickAt100 = false

This will ensure that there is always a tick mark at 100.

> this.formatString = ''

string passed to the formatter.

> this.formatString = ''

string passed to the formatter.

> this.formatString = null

alternative to tooltipFormatString will format the whole tooltip text, populating with x, y values as indicated by tooltipAxes option.

> this.formatString = ''

string passed to the formatter.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> $.jqplot.ThemeEngine.prototype.get = function( | name | )

Get and return the named theme or the active theme if no name given.

> $.jqplot.ThemeEngine.prototype.getThemeNames = function()

Return the list of theme names in this manager in alpha-numerical order.

> $.jqplot.ThemeEngine.prototype.getThemes = function()

Return a list of themes in alpha-numerical order by name.
GNU GENERAL PUBLIC LICENSE Version 2, June 1991

> this.grid = new Grid()

See Grid for grid specific options.
Object representing the grid on which the plot is drawn.

> this.gridLineColor = '#cccccc'

color of the grid lines.

> this.gridLineWidth = 1.0

width of the grid lines.

> this.groups = 1

group bars into this many groups

> this.hideZeros = false

true to not show a label for a value which is 0.

> this.highlightAlpha = null

Alpha transparency to apply when highlighting bubble.

> this.highlightColor = null

color to use when highlighting an area on a filled plot.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.highlightColors = []

an array of colors to use when highlighting a bar.

> this.highlightColors = []

An array of colors to use when highlighting a slice.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.highlightColors = []

array of colors to use when highlighting an area.

> this.highlightColors = []

an array of colors to use when highlighting a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a bubble.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a area.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over an area on a filled plot.

> this.highlightMouseDown = false

True to highlight when a mouse button is pressed over a slice.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseOver = true

True to highlight bubbles when moused over.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.highlightMouseOver = true

True to highlight area when moused over.

> this.highlightMouseOver = true

True to highlight area on a filled plot when moused over.

> this.highlightMouseOver = true

True to highlight slice when moused over.

> this.hlc = false

true if is a hi-low-close chart (no open price).
A straight horizontal line.

> this.hubRadius = null

Radius of the hub at the bottom center of gauge which the needle attaches to.
Close